==> qtjambi-sensors-6.5.7-sources.jar: io/qt/sensors/QLightSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlightsensor.html">QLightSensor</a></code></p>
 */
public class QLightSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLightSensor.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#fieldOfView-prop">QLightSensor::<wbr/>fieldOfViewChanged(qreal)</a></code></p>
     */
    @QtPropertyNotify(name="fieldOfView")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Double> fieldOfViewChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#QLightSensor">QLightSensor::<wbr/>QLightSensor(QObject*)</a></code></p>
     */
    public QLightSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLightSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#fieldOfView-prop">QLightSensor::<wbr/>fieldOfView()const</a></code></p>
     */
    @QtPropertyReader(name="fieldOfView")
    @QtUninvokable
    public final double fieldOfView(){
        return fieldOfView_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double fieldOfView_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr/>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QLightReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QLightReading reading_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#setFieldOfView">QLightSensor::<wbr/>setFieldOfView(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setFieldOfView(double fieldOfView){
        setFieldOfView_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), fieldOfView);
    }
    
    @QtUninvokable
    private native void setFieldOfView_native_qreal(long __this__nativeId, double fieldOfView);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QLightSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QLightSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QLightSensor instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLightSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLightSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #fieldOfView()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getFieldOfView() {
        return fieldOfView();
    }
}

==> qtjambi-sensors-6.6.0-sources.jar: io/qt/sensors/QLightSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlightsensor.html">QLightSensor</a></code></p>
 */
public class QLightSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLightSensor.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#fieldOfView-prop">QLightSensor::<wbr>fieldOfViewChanged(qreal)</a></code></p>
     */
    @QtPropertyNotify(name="fieldOfView")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Double> fieldOfViewChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#QLightSensor">QLightSensor::<wbr>QLightSensor(QObject*)</a></code></p>
     */
    public QLightSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLightSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#fieldOfView-prop">QLightSensor::<wbr>fieldOfView()const</a></code></p>
     */
    @QtPropertyReader(name="fieldOfView")
    @QtUninvokable
    public final double fieldOfView(){
        return fieldOfView_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double fieldOfView_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QLightReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QLightReading reading_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qlightsensor.html#setFieldOfView">QLightSensor::<wbr>setFieldOfView(qreal)</a></code></p>
     */
    @QtUninvokable
    public final void setFieldOfView(double fieldOfView){
        setFieldOfView_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), fieldOfView);
    }
    
    @QtUninvokable
    private native void setFieldOfView_native_qreal(long __this__nativeId, double fieldOfView);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QLightSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QLightSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QLightSensor instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLightSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLightSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #fieldOfView()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getFieldOfView() {
        return fieldOfView();
    }
}
